==> haskell-cryptohash-conduit-0.1.1-48-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-7y9GTYTLo244kkYMhanCvk
key: cryptohash-conduit-0.1.1-7y9GTYTLo244kkYMhanCvk
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
abi: b59933068cd44518a342583dca6e1d23
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-7y9GTYTLo244kkYMhanCvk
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.8-7nV18MBUUw27H5V6KPeFTb
    conduit-extra-1.1.15-10q3cKRpmQz8slt9iWhPKJ
    cryptohash-0.11.9-6KWjXG2Y77tCLfbEj0PLeD
    resourcet-1.1.8.1-Fz8VsTwAt9A4JeouKpXV1P transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-49-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-ANqP55lNeLv3hzCO1poMXq
key: cryptohash-conduit-0.1.1-ANqP55lNeLv3hzCO1poMXq
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
abi: 0f6e11437883df0bddee10e51d5f0456
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-ANqP55lNeLv3hzCO1poMXq
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-9cN22ayihO7Dd9VUMeez1K
    cryptohash-0.11.9-6KWjXG2Y77tCLfbEj0PLeD
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
